==> mono_1.1.8.3.orig.tar.gz: mono-1.1.8.3/mcs/class/Microsoft.JScript/Microsoft.JScript/JSFieldInfo.cs <==
//
// JSFieldInfo.cs:
//
// Author:
//	Cesar Lopez Nataren (cesar@ciencias.unam.mx)
//
// (C) 2003, Cesar Lopez Nataren
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Reflection;
using System.Globalization;

namespace Microsoft.JScript {

	public sealed class JSFieldInfo : FieldInfo {

		private FieldAttributes attr;
		private string name;
		private object value;

		internal JSFieldInfo (string name)
		{
			this.name = name;
		}

		public override FieldAttributes Attributes {
			get { return attr; }
		}


		public override Type DeclaringType {
			get { throw new NotImplementedException (); }
		}


		public override RuntimeFieldHandle FieldHandle {
			get { throw new NotImplementedException (); }
		}


		public override Type FieldType {
			get { throw new NotImplementedException (); }
		}


		public override object [] GetCustomAttributes (Type t, bool inherit)
		{
			throw new NotImplementedException ();
		}

	
		public override object [] GetCustomAttributes (bool inherit)
		{
			throw new NotImplementedException ();
		}


		public override object GetValue (object obj)
		{
			string str_name = Convert.ToString (obj);

			if (str_name == name)
				return value;
			else
				throw new NotImplementedException ();
		}


		public override bool IsDefined (Type type, bool inherit)
		{
			throw new NotImplementedException ();
		}


		public override MemberTypes MemberType {
			get { throw new NotImplementedException (); }
		}


		public override string Name {
			get { throw new NotImplementedException (); }
		}


		public override Type ReflectedType {
			get { throw new NotImplementedException (); }
		}


		public new void SetValue (object obj, object value)
		{
			string str_name = Convert.ToString (obj);
			if (str_name == name)
				this.value = value;
			else
				throw new NotImplementedException ();
		}


		public override void SetValue (object obj, object value, BindingFlags invokeAttr,
					       System.Reflection.Binder binder, CultureInfo culture)
		{
			throw new NotImplementedException ();
		}

#if NET_2_0 || BOOTSTRAP_NET_2_0
		public override FieldInfo Mono_GetGenericFieldDefinition ()
		{
			throw new NotImplementedException ();
		}
#endif
	}
}

==> mono_1.1.12.1.orig.tar.gz: mono-1.1.12.1/mcs/class/Microsoft.JScript/Microsoft.JScript/JSFieldInfo.cs <==
//
// JSFieldInfo.cs:
//
// Author:
//	Cesar Lopez Nataren (cesar@ciencias.unam.mx)
//
// (C) 2003, Cesar Lopez Nataren
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using System.Reflection;
using System.Globalization;

namespace Microsoft.JScript {

	public sealed class JSFieldInfo : FieldInfo {

		private FieldAttributes attr;
		private string name;
		private object value;

		internal JSFieldInfo (string name)
		{
			this.name = name;
		}

		public override FieldAttributes Attributes {
			get { return attr; }
		}


		public override Type DeclaringType {
			get { throw new NotImplementedException (); }
		}


		public override RuntimeFieldHandle FieldHandle {
			get { throw new NotImplementedException (); }
		}


		public override Type FieldType {
			get { throw new NotImplementedException (); }
		}


		public override object [] GetCustomAttributes (Type t, bool inherit)
		{
			throw new NotImplementedException ();
		}

	
		public override object [] GetCustomAttributes (bool inherit)
		{
			throw new NotImplementedException ();
		}


		public override object GetValue (object obj)
		{
			string str_name = Convert.ToString (obj);

			if (str_name == name)
				return value;
			else
				throw new NotImplementedException ();
		}


		public override bool IsDefined (Type type, bool inherit)
		{
			throw new NotImplementedException ();
		}


		public override MemberTypes MemberType {
			get { throw new NotImplementedException (); }
		}


		public override string Name {
			get { return name; }
		}


		public override Type ReflectedType {
			get { throw new NotImplementedException (); }
		}


		public new void SetValue (object obj, object value)
		{
			string str_name = Convert.ToString (obj);
			if (str_name == name)
				this.value = value;
			else {
				Console.WriteLine ("arg {0} != name {1}", str_name, name);
				throw new NotImplementedException ();
			}
		}


		public override void SetValue (object obj, object value, BindingFlags invokeAttr,
					       System.Reflection.Binder binder, CultureInfo culture)
		{
			SetValue (obj, value);
		}

#if NET_2_0 || BOOTSTRAP_NET_2_0
		public override FieldInfo Mono_GetGenericFieldDefinition ()
		{
			throw new NotImplementedException ();
		}
#endif
	}
}
